@@ -15,3 +15,8 @@ class MobileTicketConfiguration:
             self.queue = otrs_configuration.mobile_ticket_queue
             self.state = otrs_configuration.mobile_ticket_state
             self.priority = otrs_configuration.mobile_ticket_priority
+
+
+class MobileTicketPausedConfiguration(MobileTicketConfiguration):
+    activity_id = "Activity-7ae25cfd6f2b1d7cff02f545d0687300"
+    queue = "Serveis mòbil::Provisió mòbil::08. Provisió pausada"
