@@ -11,9 +11,13 @@ class FiberDynamicFields(InternetDynamicFields):
         Return only the specifics fields of Fiber Ticket. """
         return [
             self._df_previous_contract_pon(),
-            self._df_previous_contract_fiber_speed()
+            self._df_previous_contract_fiber_speed(),
+            self._activation_notes(),
         ]
 
+    def _activation_notes(self):
+        return DynamicField(name="consideracionsActivacio2", value=self.service_data.activation_notes)
+
     def _df_previous_contract_pon(self):
         return DynamicField(name="ponAntic", value=self.service_data.previous_contract_pon)
 
