@@ -5,7 +5,8 @@ class MobileData:
         self, order_id, phone_number, iban, email, sc_icc, icc,
         has_sim, type, previous_owner_vat, previous_owner_name,
         previous_owner_surname, previous_provider, product, delivery_street,
-        delivery_city, delivery_zip_code, delivery_state, activation_notes="", notes=""
+        delivery_city, delivery_zip_code, delivery_state, activation_notes="",
+        notes="", is_pack=False
     ):
         self.order_id = order_id
         self.phone_number = phone_number
@@ -26,3 +27,4 @@ class MobileData:
         self.delivery_state = delivery_state
         self.activation_notes = activation_notes
         self.notes = notes
+        self.is_pack = is_pack
