@@ -21,10 +21,10 @@ class UnblockMobilePackTicket:
         ticket = otrs_client.get_ticket_by_number(self.ticket_number)
 
         dynamic_fields = [
-            DynamicField(name='DynamicField_recuperarProvisio', value=1),
+            DynamicField(name='recuperarProvisio', value=1),
         ]
         otrs_client.update_ticket(
-            ticket.id,
+            ticket.tid,
             article=None,
             dynamic_fields=dynamic_fields
         )
