@@ -4,7 +4,7 @@ from mock import Mock, patch
 from otrs_somconnexio.otrs_models.ticket_factory import TicketFactory
 from otrs_somconnexio.otrs_models.adsl_ticket import ADSLTicket
 from otrs_somconnexio.otrs_models.fiber_ticket import FiberTicket
-from otrs_somconnexio.otrs_models.mobile_ticket import MobileTicket
+from otrs_somconnexio.otrs_models.mobile_ticket import (MobileTicket, MobilePausedTicket)
 
 
 class TicketFactoryIntegrationTestCase(unittest.TestCase):
@@ -27,6 +27,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'notes',
             'has_sim',
+            'is_pack',
             'activation_notes',
             'delivery_street',
             'delivery_city',
@@ -62,6 +63,60 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
         self.assertEquals(ticket.id, 234)
         self.assertIsInstance(ticket, MobileTicket)
 
+    @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
+    def test_create_mobile_paused_ticket_factory(self, MockOTRSClient):
+        mobile_data = Mock(spec=[
+            'order_id',
+            'iban',
+            'email',
+            'phone_number',
+            'sc_icc',
+            'icc',
+            'type',
+            'previous_provider',
+            'previous_owner_name',
+            'previous_owner_surname',
+            'previous_owner_vat',
+            'product',
+            'notes',
+            'has_sim',
+            'is_pack',
+            'activation_notes',
+            'delivery_street',
+            'delivery_city',
+            'delivery_zip_code',
+            'delivery_state',
+        ])
+        customer_data = Mock(spec=[
+            'id',
+            'first_name',
+            'name',
+            'vat_number',
+            'phone',
+            'street',
+            'city',
+            'zip',
+            'subdivision'])
+
+        mobile_data.service_type = 'mobile'
+        mobile_data.is_pack = True
+
+        otrs_process_ticket = Mock(spec=['id'])
+        otrs_process_ticket.id = 234
+
+        mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
+        mock_otrs_client.create_otrs_process_ticket.return_value = otrs_process_ticket
+        MockOTRSClient.return_value = mock_otrs_client
+
+        ticket = TicketFactory(
+            service_data=mobile_data,
+            customer_data=customer_data,
+        ).build()
+        ticket.create()
+
+        self.assertEquals(ticket.id, 234)
+        self.assertIsInstance(ticket, MobilePausedTicket)
+
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
     def test_create_adsl_ticket_factory(self, MockOTRSClient):
         service_data = Mock(spec=[
