@@ -117,6 +117,19 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["NIFNIESoci"], "NIFCode")
 
+    def test_order_id_field(self):
+        self.mobile_data.order_id = '2222'
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["IDpeticio"], "2222")
+
     def test_line_field(self):
         self.mobile_data.phone_number = '666666666'
 
@@ -182,7 +195,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["tipusServeiMobil"], "portabilitat")
 
-    def test_service_has_sim_field_true(self):
+    def test_service_has_sim(self):
         self.mobile_data.has_sim = True
 
         dynamic_fields = MobileDynamicFields(
@@ -193,11 +206,9 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertTrue(dynamic_fields_dct["noCobrarSIM"])
-
-    def test_service_send_sim_type_has_sim_true(self):
-        self.mobile_data.has_sim = True
+        self.assertEqual(dynamic_fields_dct["SIMrebuda"], "1")
 
+    def test_service_sim_type(self):
         dynamic_fields = MobileDynamicFields(
             self.mobile_data,
             self.customer_data,
@@ -206,9 +217,12 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["tipusEnviamentSIM"], "None")
+        self.assertEqual(
+            dynamic_fields_dct["tipusEnviamentSIM"],
+            "CH_SC_OSO_SIM"
+        )
 
-    def test_service_send_sim_type_has_sim_false(self):
+    def test_service_does_not_have_sim(self):
         self.mobile_data.has_sim = False
 
         dynamic_fields = MobileDynamicFields(
@@ -219,7 +233,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["tipusEnviamentSIM"], "CH_SC_OSO_SIM")
+        self.assertEqual(dynamic_fields_dct["SIMrebuda"], "0")
 
     def test_IBAN_field(self):
         self.mobile_data.iban = "ES6621000418401234567891"
