@@ -3,7 +3,8 @@ import unittest
 from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.mobile_ticket import MobileTicket
-from otrs_somconnexio.otrs_models.configurations.mobile_ticket import MobileTicketConfiguration
+from otrs_somconnexio.otrs_models.configurations.mobile_ticket import (
+    MobileTicketConfiguration, MobileTicketPausedConfiguration)
 
 
 class MobileTicketTestCase(unittest.TestCase):
@@ -33,6 +34,7 @@ class MobileTicketTestCase(unittest.TestCase):
 
         MockTicket.assert_called_with(expected_ticket_arguments)
 
+
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockProvisionArticle):
         mobile_data = Mock(spec=['order_id', 'notes'])
