@@ -18,8 +18,8 @@ class UnblockMobilePackTicketTestCase(unittest.TestCase):
         ticket_number = "123"
         expected_df = [object()]
         MockDF.return_value = expected_df
-        MockOTRSClient.return_value.get_ticket_by_number.return_value = Mock(spec=['id'])
-        MockOTRSClient.return_value.get_ticket_by_number.return_value.id = 321
+        MockOTRSClient.return_value.get_ticket_by_number.return_value = Mock(spec=['tid'])
+        MockOTRSClient.return_value.get_ticket_by_number.return_value.tid = 321
 
         UnblockMobilePackTicket(ticket_number).run()
 
@@ -27,11 +27,11 @@ class UnblockMobilePackTicketTestCase(unittest.TestCase):
             ticket_number
         )
         MockOTRSClient.return_value.update_ticket.assert_called_once_with(
-            MockOTRSClient.return_value.get_ticket_by_number.return_value.id,
+            MockOTRSClient.return_value.get_ticket_by_number.return_value.tid,
             article=None,
             dynamic_fields=[expected_df]
         )
         MockDF.assert_called_once_with(
-            name='DynamicField_recuperarProvisio',
+            name='recuperarProvisio',
             value=1,
         )
